@@ -20,7 +20,9 @@ class Enka:
 
     """
     _URL = "https://enka.network/u/{uid}/__data.json"
-    _REPO_BASE = 'https://raw.githubusercontent.com/Dimbreath/GenshinData/master'
+    # https://github.com/theBowja/GenshinData-1
+    # https://raw.githubusercontent.com/GrownNed/Homework/master
+    _REPO_BASE = 'https://raw.githubusercontent.com/theBowja/GenshinData-1/master'
     _LANG_URL = _REPO_BASE + '/TextMap/TextMap{lang}.json'
     _AVATAR_URL = _REPO_BASE + '/ExcelBinOutput/AvatarExcelConfigData.json'
     _TALENT_URL = _REPO_BASE + '/ExcelBinOutput/AvatarTalentExcelConfigData.json'
